@@ -12,7 +12,7 @@ use PPIx::QuoteLike::Constant qw{ @CARP_NOT };
 use PPIx::QuoteLike::Utils qw{ __instance };
 use Scalar::Util ();
 
-our $VERSION = '0.011';
+our $VERSION = '0.018';
 
 use constant SCALAR_REF	=> ref \0;
 
@@ -51,7 +51,7 @@ use constant SCALAR_REF	=> ref \0;
 		    location	=> [ 1, 1, 1, 1, -f $source ? $source :
 			undef ],
 		),
-		map { $_ => $arg{$_} } qw{ encoding postderef },
+		map { $_ => $arg{$_} } qw{ encoding },
 	    )
 	    or return;
 
@@ -100,7 +100,8 @@ sub list {
 	    qw{ type start finish };
 	push @rslt,
 	    join "\t", $self->_class_name( $obj ), $string,
-	    _format_attr( $obj, qw{ encoding failures interpolates } ),
+	    _format_attr( $obj, qw{ encoding failures interpolates
+		indentation } ),
 	    $self->_perl_version( $obj ),
 	    $self->_variables( $obj ),
 	    ;
@@ -205,10 +206,11 @@ sub _format_attr {
 
 sub _format_content {
     my ( $obj, $method, @arg ) = @_;
-    my $val = $obj->$method( @arg );
-    ref $val
-	and $val = $val->content();
-    return defined $val ? $val : '?';
+    my @val = map { $_->content() }
+	    grep { $_->significant() }
+	    $obj->$method( @arg )
+	or return '?';
+    return join '', @val;
 }
 
 sub _isa {
@@ -504,7 +506,9 @@ concatenates the result into a single string, and returns that string.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org>, or in electronic mail to the author.
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=PPIx-QuoteLike>,
+L<https://github.com/trwyant/perl-PPIx-QuoteLike/issues>, or in
+electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -512,7 +516,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2016-2020 by Thomas R. Wyant, III
+Copyright (C) 2016-2021 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
